@@ -8,9 +8,11 @@ if ($] >= 5.015) {
     warnings::register_categories(qw/version/);
 }
 
-our $VERSION = 0.99_26;
-our $CLASS = 'version';
-our (@ISA, $STRICT, $LAX);
+use vars qw(@ISA $VERSION $CLASS $STRICT $LAX *declare *qv);
+
+$VERSION = '0.9912_01';
+$VERSION = eval $VERSION;
+$CLASS = 'version';
 
 # !!!!Delete this next block completely when adding to Perl core!!!!
 {
@@ -63,11 +65,7 @@ require version::regex;
 *version::is_lax = \&version::regex::is_lax;
 *version::is_strict = \&version::regex::is_strict;
 *LAX = \$version::regex::LAX;
-*LAX_DECIMAL_VERSION = \$version::regex::LAX_DECIMAL_VERSION;
-*LAX_DOTTED_DECIMAL_VERSION = \$version::regex::LAX_DOTTED_DECIMAL_VERSION;
 *STRICT = \$version::regex::STRICT;
-*STRICT_DECIMAL_VERSION = \$version::regex::STRICT_DECIMAL_VERSION;
-*STRICT_DOTTED_DECIMAL_VERSION = \$version::regex::STRICT_DOTTED_DECIMAL_VERSION;
 
 sub import {
     no strict 'refs';
