@@ -122,11 +122,10 @@ use strict;
 use warnings::register;
 
 use Config;
-
-our $VERSION = 0.99_26;
-our $CLASS = 'version::vpp';
-our ($LAX, $STRICT, $WARN_CATEGORY);
-
+use vars qw($VERSION $CLASS @ISA $LAX $STRICT $WARN_CATEGORY);
+$VERSION = '0.9912_01';
+$VERSION = eval $VERSION;
+$CLASS = 'version::vpp';
 if ($] > 5.015) {
     warnings::register_categories(qw/version/);
     $WARN_CATEGORY = 'version';
@@ -777,7 +776,6 @@ sub stringify {
 
 sub vcmp {
     my ($left,$right,$swap) = @_;
-    die "Usage: version::vcmp(lobj, robj, ...)" if @_ < 2;
     my $class = ref($left);
     unless ( UNIVERSAL::isa($right, $class) ) {
 	$right = $class->new($right);
@@ -927,7 +925,6 @@ sub _find_magic_vstring {
 	    $magic = $magic->MOREMAGIC;
 	}
     }
-    $tvalue =~ tr/_//d;
     return $tvalue;
 }
 
