@@ -4,9 +4,10 @@ package version::vxs;
 use v5.10;
 use strict;
 
-our $VERSION = 0.99_26;
-our $CLASS = 'version::vxs';
-our @ISA;
+use vars qw(@ISA $VERSION $CLASS );
+$VERSION = '0.9912_01';
+$VERSION = eval $VERSION;
+$CLASS = 'version::vxs';
 
 eval {
     require XSLoader;
